### Name: mi.pooled
### Title: Modeling Functions for Multiply Imputed Dataset
### Aliases: mi.pooled mi.pooled-class lm.mi glm.mi bayesglm.mi polr.mi
###   bayespolr.mi lmer.mi glmer.mi print.mi.pooled
###   display,mi.pooled-method coef,mi.pooled-method
###   coefficients,mi.pooled-method se.coef,mi.pooled-method
### Keywords: models manip

### ** Examples

  # true data
  n <- 100
  x <- rbinom(n,1,.45) 
  z <- ordered(rep(seq(1, 5),n)[sample(1:n, n)])
  y <- rnorm(n)
  group <- rep(1:10, 10)

  # create artificial missingness
  dat.xy <- data.frame(x, z, y)
  dat.xy <- mi:::.create.missing(dat.xy, pct.mis=10)  

  # imputation 
  dat.mi <- mi(dat.xy, n.iter=6, preprocess=FALSE, add.noise=FALSE)

  # fit models
  M1 <- lm.mi(y ~ x + z, dat.mi)
  display(M1)
  coef(M1)
  se.coef(M1)

  M2 <- glm.mi(x ~ y , dat.mi, family = binomial(link="logit"))
  display(M2)
  coef(M2)
  se.coef(M2)

  M3 <- bayesglm.mi(x ~ y , dat.mi, family = binomial(link="logit"))
  display(M3)
  coef(M3)
  se.coef(M3)

  M4 <- polr.mi(ordered(z) ~  y, dat.mi)
  display(M4)
  coef(M4)
  se.coef(M4)

  M5 <- bayespolr.mi(ordered(z) ~  y, dat.mi)
  display(M5)
  coef(M5)
  se.coef(M5)

  M6 <- lmer.mi(y ~ x  + (1|group), dat.mi)
  display(M6)
  coef(M6)
  se.coef(M6)

  M7 <- glmer.mi(x ~ y  + (1|group), dat.mi, family = binomial(link="logit"))
  display(M7)
  coef(M7)
  se.coef(M7)  



